@@ -7,20 +7,18 @@ module Hledger.Web.Options
 where
 import Prelude
 import Data.Maybe
-import Distribution.PackageDescription.TH (packageVariable, package, pkgName, pkgVersion)
 import System.Console.CmdArgs
 import System.Console.CmdArgs.Explicit
 
 import Hledger.Cli hiding (progname,version,prognameandversion)
-import Hledger.Web.Settings
+import Settings
 
 progname, version :: String
-#if HADDOCK
-progname = ""
-version  = ""
+progname = "hledger-web"
+#ifdef VERSION
+version = VERSION
 #else
-progname = $(packageVariable (pkgName . package))
-version  = $(packageVariable (pkgVersion . package))
+version = ""
 #endif
 prognameandversion :: String
 prognameandversion = progname ++ " " ++ version :: String
@@ -30,7 +28,8 @@ defbaseurlexample = (reverse $ drop 4 $ reverse $ defbaseurl defport) ++ "PORT"
 
 webflags :: [Flag [([Char], [Char])]]
 webflags = [
-  flagReq ["base-url"]  (\s opts -> Right $ setopt "base-url" s opts) "URL" ("set the base url (default: "++defbaseurlexample++")")
+  flagNone ["server"]  (setboolopt "server") ("log requests, don't auto-exit")
+ ,flagReq ["base-url"]  (\s opts -> Right $ setopt "base-url" s opts) "URL" ("set the base url (default: "++defbaseurlexample++")")
  ,flagReq ["port"]  (\s opts -> Right $ setopt "port" s opts) "PORT" ("listen on this tcp port (default: "++show defport++")")
  ]
  
@@ -50,7 +49,8 @@ webmode =  (mode "hledger-web" [("command","web")]
 
 -- hledger-web options, used in hledger-web and above
 data WebOpts = WebOpts {
-     base_url_ :: String
+     server_   :: Bool
+    ,base_url_ :: String
     ,port_     :: Int
     ,cliopts_  :: CliOpts
  } deriving (Show)
@@ -60,6 +60,7 @@ defwebopts = WebOpts
     def
     def
     def
+    def
 
 -- instance Default WebOpts where def = defwebopts
 
@@ -69,6 +70,7 @@ toWebOpts rawopts = do
   let p = fromMaybe defport $ maybeintopt "port" rawopts
   return defwebopts {
               port_ = p
+             ,server_ = boolopt "server" rawopts
              ,base_url_ = maybe (defbaseurl p) stripTrailingSlash $ maybestringopt "base-url" rawopts
              ,cliopts_   = cliopts
              }
@@ -77,7 +79,7 @@ toWebOpts rawopts = do
 
 checkWebOpts :: WebOpts -> IO WebOpts
 checkWebOpts opts = do
-  checkCliOpts $ cliopts_ opts
+  _ <- checkCliOpts $ cliopts_ opts
   return opts
 
 getHledgerWebOpts :: IO WebOpts
